==> kara-uc-1.1.93.tgz: package/src/kara-uc/components/UCInfo/headIcon/index.js <==
import React from 'react'
import Modal from 'react-modal-plugin'
import Avatar from '../avatar/index'
import css from '../index.scss'
import base64 from '../../../assets/img/base64'
import {Tost} from "karaui";

export default class HeadIcon extends React.Component{
  constructor(props)
  {
    super(props)
    this.state = {
      file: null,
      showEditHead: false,
      bigHeadModal: false,
    }
    this.aFile = React.createRef()
  }

  handleErrorImg = (e) => {
    e.target.src = base64.userHead;
  }

  openBigHead = () => {
    this.setState({
      bigHeadModal: true,
    })
  }

  closeBigHead = () => {
    this.setState({
      bigHeadModal: false,
    })
  }

  hiddenModal = () => {
    this.setState({showEditHead: false})
  }

  avatarFile = (e) => {
    const fileName = e.target.files[0].name;
    const fileSize = e.target.files[0].size;
    const typeName = fileName.substring(fileName.lastIndexOf('.')+1).toLocaleLowerCase();
    if (!(typeName === "jpg" || typeName === "bmp" || typeName === "png" || typeName === "jpeg")) {
      alert('格式不正确')
      this.aFile.current.value = null
      return
    }
    if(fileSize/1024/1024 > 10){
      alert('图片太大')
      this.aFile.current.value = null
      return
    }
    this.setState({showEditHead: true,file:e.target.files[0]},()=>{
      this.aFile.current.value = null // 重置input防止用户下一次选择同一个图片
    })
  }

  uploadIcon = (blob) => {
    const {httpAgent, UCInfoStore} = this.props
    httpAgent.post('/file/upload/icon',blob,null,null,{'Content-Type': 'application/octet-stream;charset=UTF-8'}).then(
      res => {
        if(res && res.resultCode && res.resultCode === '000000') {
          UCInfoStore.uploadIcon(res)
          Tost({type:'success',msg:'修改成功',time:4})
        }
        else {
          Tost({type:'error',msg:'修改失败',time:4})
        }
      }
    )
  }

  render() {
    console.log('head',this.props)
    const parent = document.getElementById('app') || document.body
    const {headIcon,user,lang,UCInfoStore} = this.props
    const {showEditHead,file, bigHeadModal} = this.state
    const avatarProps = {
      afile: file,
      modalHidden: this.hiddenModal,
      cancleAvatarFun: this.hiddenModal,
      uploadIcon: this.uploadIcon,
      uploadImageTypeError: ()=>{},
      uploadImageSizeError: ()=>{}
    }
    return(<div className={css.headIcon}>
      <div>
        <img src={headIcon} alt='' onError={this.handleErrorImg} onClick={this.openBigHead} />
      </div>
      <div>
        <span>{UCInfoStore.userCard.accountName}&nbsp;
          <span style={{fontSize:'18px'}}>({UCInfoStore.userCard.staffCode})</span>
          &nbsp;
          <i className={`kuc-iconfont ${user.gender==='M' ? 'kuc-male s-man' : 'kuc-female s-women'}`}></i></span>
        <span>
              {/*<a className={css.uploadavatar} >*/}
                <i className='kuc-iconfont kuc-edit s-primary'></i>&nbsp;<span>{lang.updateAvatar}</span>
                <input ref={this.aFile} type="file" onChange={this.avatarFile} />
               {/*</a>*/}
              </span>
      </div>
      <Modal show={showEditHead} onMask={this.hiddenModal} parent={parent}>
        <Avatar {...avatarProps}/>
      </Modal>
      <Modal show={bigHeadModal} onMask={this.closeBigHead} parent={parent}>
        <img className={css.bigHead} src={headIcon} alt='' onError={this.handleErrorImg} />
      </Modal>
    </div>)
  }
}

==> kara-uc-1.2.28.tgz: package/src/kara-uc/components/UCInfo/headIcon/index.js <==
import React from 'react'
import Modal from 'react-modal-plugin'
import Avatar from '../avatar/index'
import css from '../index.scss'
import base64 from '../../../assets/img/base64'
import {Tost} from "karaui";

export default class HeadIcon extends React.Component{
  constructor(props)
  {
    super(props)
    this.state = {
      file: null,
      showEditHead: false,
      bigHeadModal: false,
    }
    this.aFile = React.createRef()
  }

  handleErrorImg = (e) => {
    e.target.src = base64.userHead;
  }

  openBigHead = () => {
    this.setState({
      bigHeadModal: true,
    })
  }

  closeBigHead = () => {
    this.setState({
      bigHeadModal: false,
    })
  }

  hiddenModal = () => {
    this.setState({showEditHead: false})
  }

  avatarFile = (e) => {
    const fileName = e.target.files[0].name;
    const fileSize = e.target.files[0].size;
    const typeName = fileName.substring(fileName.lastIndexOf('.')+1).toLocaleLowerCase();
    if (!(typeName === "jpg" || typeName === "bmp" || typeName === "png" || typeName === "jpeg")) {
      alert('格式不正确')
      this.aFile.current.value = null
      return
    }
    if(fileSize/1024/1024 > 10){
      alert('图片太大')
      this.aFile.current.value = null
      return
    }
    this.setState({showEditHead: true,file:e.target.files[0]},()=>{
      this.aFile.current.value = null // 重置input防止用户下一次选择同一个图片
    })
  }

  uploadIcon = (blob) => {
    const {httpAgent, UCInfoStore} = this.props
    httpAgent.post('/file/upload/icon',blob,null,null,{'Content-Type': 'application/octet-stream;charset=UTF-8'}).then(
      res => {
        if(res && res.resultCode && res.resultCode === '000000') {
          UCInfoStore.uploadIcon(res)
          Tost({type:'success',msg:'修改成功',time:4})
        }
        else {
          Tost({type:'error',msg:'修改失败',time:4})
        }
      }
    )
  }

  render() {
    // console.log('head',this.props)
    const parent = document.getElementById('app') || document.body
    const {headIcon,user,lang,UCInfoStore} = this.props
    const {showEditHead,file, bigHeadModal} = this.state
    const avatarProps = {
      afile: file,
      modalHidden: this.hiddenModal,
      cancleAvatarFun: this.hiddenModal,
      uploadIcon: this.uploadIcon,
      uploadImageTypeError: ()=>{},
      uploadImageSizeError: ()=>{}
    }
    return(<div className={css.headIcon}>
      <div>
        <img src={headIcon} alt='' onError={this.handleErrorImg} onClick={this.openBigHead} />
      </div>
      <div>
        <span>{UCInfoStore.userCard.accountName}&nbsp;
          <span style={{fontSize:'18px'}}>({UCInfoStore.userCard.staffCode})</span>
          &nbsp;
          <i className={`kuc-iconfont ${user.gender==='M' ? 'kuc-male s-man' : 'kuc-female s-women'}`}></i></span>
        <span>
              {/*<a className={css.uploadavatar} >*/}
                <i className='kuc-iconfont kuc-edit s-primary'></i>&nbsp;<span>{lang.updateAvatar}</span>
                <input ref={this.aFile} type="file" onChange={this.avatarFile} />
               {/*</a>*/}
              </span>
      </div>
      <Modal show={showEditHead} onMask={this.hiddenModal} parent={parent}>
        <Avatar {...avatarProps}/>
      </Modal>
      <Modal show={bigHeadModal} onMask={this.closeBigHead} parent={parent}>
        <img className={css.bigHead} src={headIcon} alt='' onError={this.handleErrorImg} />
      </Modal>
    </div>)
  }
}
